==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/af_ZA.js <==
OC.L10N.register(
    "files",
    {
    "Unshare" : "Deel terug neem",
    "Folder" : "Omslag",
    "Settings" : "Instellings",
    "Unknown error" : "Onbekende fout",
    "All files" : "Alle lêers",
    "File could not be found" : "Lêer kon nie gevind word nie",
    "Home" : "Tuis",
    "Close" : "Sluit",
    "Favorites" : "Gunstelinge",
    "Target folder does not exist any more" : "Teikenvouer bestaan nie meer nie",
    "Actions" : "Aksies",
    "Download" : "Laai Af",
    "Rename" : "Hernoem",
    "Delete" : "Skrap",
    "Files" : "Lêers",
    "Details" : "Details",
    "Select" : "Kies",
    "Pending" : "Hangend",
    "Invalid path" : "Ongeldige pad",
    "This operation is forbidden" : "Hierdie bewerking is verbode",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hierdie gids is onbeskikbaar, gaan die logs na of kontak die stelseladministrateur",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Gewysig",
    "New" : "Nuut",
    "Path" : "Pad",
    "Favorite" : "Gunsteling",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privaatskakel: Slegs mense wat toegang tot die lêer/vouer het kan dit gebruik. Gebruik dit vir uself as permanente skakel of om ander na lêer binne delings te rig.",
    "New folder" : "Nuwe vouer",
    "Upload cancelled." : "Oplaai gekanselleer.",
    "You created %1$s" : "U het %1$s geskep",
    "You changed %1$s" : "U het %1$s verander",
    "You deleted %1$s" : "U het %1$s geskrap",
    "Changed by %2$s" : "Verander deur %2$s",
    "Deleted by %2$s" : "Geskrap deur %2$s",
    "Show hidden files" : "Toon versteekte lêers",
    "WebDAV" : "WebDAV",
    "No files in here" : "Hier is geen lêers nie",
    "No entries found in this folder" : "Geen inskrywings in hierdie vouer gevind",
    "Select all" : "Kies alle",
    "No favorites" : "Geen gunstelinge",
    "Text file" : "Tekslêer",
    "New text file.txt" : "Nuwe tekslêer.txt",
    "Processing files..." : "Verwerk tans lêers…",
    "Uploading..." : "Laai tans op…",
    "..." : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "{newName} already exists" : "{newName} bestaan reeds",
    "{dirs} and {files}" : "{dirs} en {files}",
    "File name cannot be empty." : "Lêernaam mag nie leeg wees nie.",
    "{newname} already exists" : "{newname} bestaan reeds",
    "Upload" : "Laai Op",
    "%2$s created %1$s" : "%2$s het %1$s geskep",
    "%1$s was created in a public folder" : "%1$s is in ’n openbare vouer geskep",
    "%2$s changed %1$s" : "%2$s het %1$s verander",
    "%2$s deleted %1$s" : "%2$s het %1$s geskrap",
    "Upload (max. %s)" : "Laai op (maks. %s)",
    "Unknown user" : "Onbekende gebruiker"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/af_ZA.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Onbekende fout",
    "All files" : "Alle lêers",
    "File could not be found" : "Lêer kon nie gevind word nie",
    "Home" : "Tuis",
    "Close" : "Sluit",
    "Favorites" : "Gunstelinge",
    "Upload cancelled." : "Oplaai gekanselleer.",
    "Processing files..." : "Verwerk tans lêers…",
    "Target folder \"{dir}\" does not exist any more" : "Teikenvouer “{dir}” bestaan nie meer nie",
    "Target folder does not exist any more" : "Teikenvouer bestaan nie meer nie",
    "Uploading..." : "Laai tans op…",
    "..." : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "Actions" : "Aksies",
    "Download" : "Laai Af",
    "Rename" : "Hernoem",
    "Delete" : "Skrap",
    "Unshare" : "Deel terug neem",
    "Files" : "Lêers",
    "Details" : "Details",
    "Select" : "Kies",
    "Pending" : "Hangend",
    "Invalid path" : "Ongeldige pad",
    "This operation is forbidden" : "Hierdie bewerking is verbode",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hierdie gids is onbeskikbaar, gaan die logs na of kontak die stelseladministrateur",
    "group" : "groep",
    "Could not move \"{file}\", target exists" : "Kon nie “{file}” skuif nie, teiken bestaan",
    "Could not move \"{file}\"" : "Kon nie “{file}” skuif nie",
    "{newName} already exists" : "{newName} bestaan reeds",
    "Could not create file \"{file}\"" : "Kon nie lêer “{file}” skep nie",
    "Could not create file \"{file}\" because it already exists" : "Kon nie ’n lêer “{file}” skep nie omdat dit reeds bestaan",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Gewysig",
    "_%n folder_::_%n folders_" : ["%n vouer","%n vouers"],
    "_%n file_::_%n files_" : ["%n lêer","%n lêers"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "New" : "Nuut",
    "Unknown user" : "Onbekende gebruiker",
    "\"{name}\" is an invalid file name." : "“{naam}” is ’n ongeldige lêernaam.",
    "File name cannot be empty." : "Lêernaam mag nie leeg wees nie.",
    "File name cannot contain \"/\"." : "Lêer kan nie “/” bevat nie.",
    "\"{name}\" has a forbidden file type/extension." : "“{name}” het ’n verbode lêertipe/uitbreiding.",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n greep","%n grepe"],
    "Favorite" : "Gunsteling",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privaatskakel: Slegs mense wat toegang tot die lêer/vouer het kan dit gebruik. Gebruik dit vir uself as permanente skakel of om ander na lêer binne delings te rig.",
    "Folder" : "Omslag",
    "New folder" : "Nuwe vouer",
    "{newname} already exists" : "{newname} bestaan reeds",
    "Upload" : "Laai Op",
    "You created %1$s" : "U het %1$s geskep",
    "%2$s created %1$s" : "%2$s het %1$s geskep",
    "%1$s was created in a public folder" : "%1$s is in ’n openbare vouer geskep",
    "You changed %1$s" : "U het %1$s verander",
    "%2$s changed %1$s" : "%2$s het %1$s verander",
    "You deleted %1$s" : "U het %1$s geskrap",
    "%2$s deleted %1$s" : "%2$s het %1$s geskrap",
    "Changed by %2$s" : "Verander deur %2$s",
    "Deleted by %2$s" : "Geskrap deur %2$s",
    "Upload (max. %s)" : "Laai op (maks. %s)",
    "Settings" : "Instellings",
    "Show hidden files" : "Toon versteekte lêers",
    "WebDAV" : "WebDAV",
    "No files in here" : "Hier is geen lêers nie",
    "No entries found in this folder" : "Geen inskrywings in hierdie vouer gevind",
    "Select all" : "Kies alle",
    "No favorites" : "Geen gunstelinge",
    "Text file" : "Tekslêer",
    "New text file.txt" : "Nuwe tekslêer.txt"
},
"nplurals=2; plural=(n != 1);");
